@@ -23,7 +23,7 @@ describe 'tripleo::profile::base::cinder::api' do
     end
 
     let(:pre_condition) do
-      "class { '::tripleo::profile::base::cinder': step => #{params[:step]}, oslomsg_rpc_hosts => ['127.0.0.1'] }"
+      "class { 'tripleo::profile::base::cinder': step => #{params[:step]}, oslomsg_rpc_hosts => ['127.0.0.1'] }"
     end
 
     context 'with step less than 3' do
