@@ -25,7 +25,7 @@ describe 'tripleo::profile::base::manila::api' do
 
     let(:pre_condition) do
       <<-eos
-      class { '::tripleo::profile::base::manila':
+      class { 'tripleo::profile::base::manila':
         step => #{params[:step]},
         oslomsg_rpc_hosts    => [ 'localhost' ],
         oslomsg_rpc_username => 'manila',
@@ -129,29 +129,6 @@ eos
         is_expected.to contain_class('tripleo::profile::base::manila::api')
       }
     end
-
-    context 'with custom protocols' do
-      let(:params) { {
-        :step                    => 4,
-        :bootstrap_node          => 'node.example.com',
-        :backend_generic_enabled => true,
-        :backend_cephfs_enabled  => true,
-        :enabled_share_protocols => ['CIFS', 'CEPHFS'],
-      } }
-
-      it {
-        is_expected.to contain_class('tripleo::profile::base::manila::api')
-        is_expected.to contain_class('tripleo::profile::base::manila')
-        is_expected.to contain_class('tripleo::profile::base::manila::authtoken')
-        is_expected.to contain_class('tripleo::profile::base::manila::api')
-        is_expected.to contain_class('tripleo::profile::base::apache')
-        is_expected.to contain_class('manila::api').with(
-          :enabled_share_protocols => 'CIFS,CEPHFS'
-        )
-        is_expected.to contain_class('manila::wsgi::apache')
-        is_expected.to contain_class('tripleo::profile::base::manila::api')
-      }
-    end
   end
 
 
