@@ -57,6 +57,7 @@ describe 'tripleo::profile::pacemaker::cinder::backup_bundle' do
       let(:params) { {
         :step                       => 5,
         :cinder_backup_docker_image => 'c-bak-docker-image',
+        :log_driver                 => 'journald',
       } }
 
       context 'with default inputs' do
@@ -80,12 +81,13 @@ describe 'tripleo::profile::pacemaker::cinder::backup_bundle' do
           params.merge!({
             :docker_volumes     => ['/src/1:/tgt/1', '/src/2:/tgt/2:ro', '/src/3:/tgt/3:ro,z'],
             :docker_environment => ['RIGHT=LEFT', 'UP=DOWN'],
+            :log_driver         => 'k8s-file',
           })
         end
         it 'should create custom cinder-backup resource bundle' do
           is_expected.to contain_pacemaker__resource__bundle('openstack-cinder-backup').with(
             :image        => 'c-bak-docker-image',
-            :options      => '--ipc=host --privileged=true --user=root --log-driver=journald -e RIGHT=LEFT -e UP=DOWN',
+            :options      => '--ipc=host --privileged=true --user=root --log-driver=k8s-file -e RIGHT=LEFT -e UP=DOWN',
             :storage_maps => {
               'cinder-backup-src-1' => {
                 'source-dir' => '/src/1',
